;; Generated package description from sapling.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "sapling" "0.2.2" "Magit-like interface for Sapling" '((emacs "26.1")) :commit "0f833a51cf7515470fe0348661133cf4ce8f3bc2" :authors '(("Swithin Chan" . "swithinchan@yahoo.com.hk")) :maintainer '("Swithin Chan" . "swithinchan@yahoo.com.hk") :keywords '("tools" "vc") :url "https://github.com/swithinchan/sapling/")
